pub trait FallbackPolicy<Response> {
// Required method
fn should_fallback(&self, result: &Result<Response, BoxedError>) -> bool;
}Expand description
Decides if a Fallback service should call its fallback service.
Required Methods
Sourcefn should_fallback(&self, result: &Result<Response, BoxedError>) -> bool
fn should_fallback(&self, result: &Result<Response, BoxedError>) -> bool
Returns true if the fallback service should handle this request.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".